#!/usr/bin/env python
# -*- coding: utf-8 -*-
###########################################################################
# Eole NG - 2009
# Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
# Licence CeCill  cf /root/LicenceEole.txt
# eole@ac-dijon.fr
#
# gen_databases.py
#
# Génération de base de données mysql
#
###########################################################################
"""
    Outil de génération de base de données
"""
from os.path import isfile

from creole.eosfunc import gen_random

from eolesql.log import log_console, log
from eolesql.db_layer import DB
from eolesql.collect_gen import load_apps_conf
from eolesql.mysqltest import mysql_ok
from eolesql.db_cmd import dump_sql_file

from mysql_pwd import mysql_root_passwd, get_password_conf, mod_passwords

REMOVE_BDD_QUERY = "DROP DATABASE IF EXISTS %s;"


def gen_databases(db_to_gen_dict):
    """
        Génération des bases de données
        une base : {'test':fonction de test,
                    'filenames':'nom des fichiers sql à dumper',
                    'pregen': 'requête sql à éxécuter avant la
                               génération'(facultatif),
                    'postgen': 'requête sql à éxécuter après la
                                génération'(facultatif),
                    }
    """
    new_root_password = gen_random(10)
    mysql_root_passwd(new_root_password)
    db_handler = DB(dict(host='localhost',
                    user='root',
                    passwd=new_root_password))

    for app_name, db_conf in db_to_gen_dict.items():
        if db_conf['test']():
            log_console("# Ajout de la base de données %s" % (app_name,), 1)
            if db_conf.has_key('pregen'):
                log(" + Éxécution de la requête 'pregen'", 2)
                db_conf['pregen'](db_handler)
            if db_conf.has_key('filenames'):
                for filename in db_conf['filenames']:
                    if isfile(filename):
                        log(" + Création de la base de données", 2)
                        dump_sql_file(new_root_password, filename)
                    else:
                        log(" - Erreur : Il manque le fichier %s" % (
                                                        filename,), 1)
            else:
                log_console(" - Erreur : Il manque des éléments de \
configuration pour l'ajout de base de données.", 1)
            if db_conf.has_key('postgen'):
                log(" + Éxécution de la requête 'postgen'", 2)
                db_conf['postgen'](db_handler)
        else:
            log_console(" + La base %s existe déjà +" % (app_name,), 1)
    new_root_pass = gen_random(10)
    mysql_root_passwd(new_root_pass)
    modif_pass_dict = get_password_conf()
    mod_passwords(new_root_pass, modif_pass_dict)

if __name__ == '__main__':
    log_console("## Génération de base de données ##")
    mysql_ok()
    DB_TO_GEN = load_apps_conf()
    if DB_TO_GEN:
        gen_databases(DB_TO_GEN)
    else:
        log(" - Aucune configuration de base de données trouvée.")
